summaryrefslogtreecommitdiff
path: root/chromium/net/spdy/server_push_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/spdy/server_push_delegate.h')
-rw-r--r--chromium/net/spdy/server_push_delegate.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chromium/net/spdy/server_push_delegate.h b/chromium/net/spdy/server_push_delegate.h
index 16341091374..4631fddb39f 100644
--- a/chromium/net/spdy/server_push_delegate.h
+++ b/chromium/net/spdy/server_push_delegate.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -28,8 +28,8 @@ class NET_EXPORT_PRIVATE ServerPushDelegate {
// Gets the URL of the pushed request.
virtual const GURL& GetURL() const = 0;
- // Gets the network isolation key for the pushed request.
- virtual NetworkIsolationKey GetNetworkIsolationKey() const = 0;
+ // Gets the network anonymization key for the pushed request.
+ virtual NetworkAnonymizationKey GetNetworkAnonymizationKey() const = 0;
};
virtual ~ServerPushDelegate() = default;